from base.extension import BaseExtension
import pytest

from blackfennec_doubles.double_dummy import Dummy
from blackfennec_doubles.type_system.double_type_registry import \
    TypeRegistryMock
from blackfennec_doubles.extension.double_view_factory_registry import \
    ViewFactoryRegistryMock
from blackfennec_doubles.type_system.double_type_loader import TypeLoaderMock
from blackfennec.extension.extension_api import ExtensionApi


@pytest.fixture()
def extension_api():
    type_registry = TypeRegistryMock()
    return ExtensionApi(
        presenter_registry=Dummy('PresenterRegistry'),
        type_registry=type_registry,
        interpretation_service=Dummy('InterpretationService'),
        view_factory=Dummy('ViewFactory'),
        view_factory_registry=ViewFactoryRegistryMock(),
        type_loader=TypeLoaderMock(type_registry),
        action_registry=Dummy('ActionRegistry'),
        document_registry=Dummy('DocumentRegistry'),
        document_factory=Dummy('DocumentFactory'),
        ui_service_registry=Dummy('UiServiceRegistry'),
    )


@pytest.fixture()
def extension(extension_api):
    return BaseExtension(extension_api)


def test_can_construct(extension):
    assert extension


def test_can_get_name(extension):
    assert extension.name == 'base'


def test_can_get_dependencies(extension):
    assert extension.dependencies == {'core'}


def test_can_activate(extension):
    extension.activate()


def test_can_deactivate(extension):
    extension.activate()
    extension.deactivate()
